@@ -1,7 +1,7 @@
 package Perinci::Sub::Complete;
 
-our $DATE = '2015-08-11'; # DATE
-our $VERSION = '0.80'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.81'; # VERSION
 
 use 5.010001;
 use strict;
@@ -963,7 +963,7 @@ Perinci::Sub::Complete - Complete command-line argument using Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.80 of Perinci::Sub::Complete (from Perl distribution Perinci-Sub-Complete), released on 2015-08-11.
+This document describes version 0.81 of Perinci::Sub::Complete (from Perl distribution Perinci-Sub-Complete), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
@@ -977,9 +977,8 @@ this module.
 
 =head2 complete_arg_elem(%args) -> array
 
-{en_US Given argument name and function metadata, complete array element}.
+Given argument name and function metadata, complete array element.
 
-{en_US 
 Will attempt to complete using the completion routine specified in the argument
 specification (the C<completion> property, or in the case of C<complete_arg_elem>
 function, the C<element_completion> property), or if that is not specified, from
@@ -1009,7 +1008,6 @@ Completion routine should return a completion answer structure (described in
 C<Complete>) which is either a hash or an array. The simplest form of answer is
 just to return an array of strings. Completion routine can also return undef to
 express declination.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -1017,39 +1015,36 @@ Arguments ('*' denotes required arguments):
 
 =item * B<arg>* => I<str>
 
-{en_US Argument name}.
+Argument name.
 
 =item * B<args> => I<hash>
 
-{en_US Collected arguments so far, will be passed to completion routines}.
+Collected arguments so far, will be passed to completion routines.
 
 =item * B<ci> => I<bool>
 
-{en_US Whether to be case-insensitive}.
+Whether to be case-insensitive.
 
 =item * B<extras> => I<hash>
 
-{en_US Add extra arguments to completion routine}.
+Add extra arguments to completion routine.
 
-{en_US 
 The keys from this C<extras> hash will be merged into the final C<%args> passed to
 completion routines. Note that standard keys like C<word>, C<cword>, C<ci>, and so
 on as described in the function description will not be overwritten by this.
-}
 
 =item * B<index> => I<int>
 
-{en_US Index of element to complete}.
+Index of element to complete.
 
 =item * B<meta>* => I<hash>
 
-{en_US Rinci function metadata, must be normalized}.
+Rinci function metadata, must be normalized.
 
 =item * B<riap_client> => I<obj>
 
-{en_US Optional, to perform complete_arg_val to the server}.
+Optional, to perform complete_arg_val to the server.
 
-{en_US 
 When the argument spec in the Rinci metadata contains C<completion> key, this
 means there is custom completion code for that argument. However, if retrieved
 from a remote server, sometimes the C<completion> key no longer contains the code
@@ -1059,27 +1054,22 @@ on the server.
 If supplied this argument and te C<riap_server_url> argument, the function will
 try to request to the server (via Riap request C<complete_arg_val>). Otherwise,
 the function will just give up/decline completing.
-}
 
 =item * B<riap_server_url> => I<str>
 
-{en_US Optional, to perform complete_arg_val to the server}.
+Optional, to perform complete_arg_val to the server.
 
-{en_US 
 See the C<riap_client> argument.
-}
 
 =item * B<riap_uri> => I<str>
 
-{en_US Optional, to perform complete_arg_val to the server}.
+Optional, to perform complete_arg_val to the server.
 
-{en_US 
 See the C<riap_client> argument.
-}
 
 =item * B<word> => I<str> (default: "")
 
-{en_US Word to be completed}.
+Word to be completed.
 
 =back
 
@@ -1088,9 +1078,8 @@ Return value:  (array)
 
 =head2 complete_arg_val(%args) -> array
 
-{en_US Given argument name and function metadata, complete value}.
+Given argument name and function metadata, complete value.
 
-{en_US 
 Will attempt to complete using the completion routine specified in the argument
 specification (the C<completion> property, or in the case of C<complete_arg_elem>
 function, the C<element_completion> property), or if that is not specified, from
@@ -1120,7 +1109,6 @@ Completion routine should return a completion answer structure (described in
 C<Complete>) which is either a hash or an array. The simplest form of answer is
 just to return an array of strings. Completion routine can also return undef to
 express declination.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -1128,35 +1116,32 @@ Arguments ('*' denotes required arguments):
 
 =item * B<arg>* => I<str>
 
-{en_US Argument name}.
+Argument name.
 
 =item * B<args> => I<hash>
 
-{en_US Collected arguments so far, will be passed to completion routines}.
+Collected arguments so far, will be passed to completion routines.
 
 =item * B<ci> => I<bool>
 
-{en_US Whether to be case-insensitive}.
+Whether to be case-insensitive.
 
 =item * B<extras> => I<hash>
 
-{en_US Add extra arguments to completion routine}.
+Add extra arguments to completion routine.
 
-{en_US 
 The keys from this C<extras> hash will be merged into the final C<%args> passed to
 completion routines. Note that standard keys like C<word>, C<cword>, C<ci>, and so
 on as described in the function description will not be overwritten by this.
-}
 
 =item * B<meta>* => I<hash>
 
-{en_US Rinci function metadata, must be normalized}.
+Rinci function metadata, must be normalized.
 
 =item * B<riap_client> => I<obj>
 
-{en_US Optional, to perform complete_arg_val to the server}.
+Optional, to perform complete_arg_val to the server.
 
-{en_US 
 When the argument spec in the Rinci metadata contains C<completion> key, this
 means there is custom completion code for that argument. However, if retrieved
 from a remote server, sometimes the C<completion> key no longer contains the code
@@ -1166,27 +1151,22 @@ on the server.
 If supplied this argument and te C<riap_server_url> argument, the function will
 try to request to the server (via Riap request C<complete_arg_val>). Otherwise,
 the function will just give up/decline completing.
-}
 
 =item * B<riap_server_url> => I<str>
 
-{en_US Optional, to perform complete_arg_val to the server}.
+Optional, to perform complete_arg_val to the server.
 
-{en_US 
 See the C<riap_client> argument.
-}
 
 =item * B<riap_uri> => I<str>
 
-{en_US Optional, to perform complete_arg_val to the server}.
+Optional, to perform complete_arg_val to the server.
 
-{en_US 
 See the C<riap_client> argument.
-}
 
 =item * B<word> => I<str> (default: "")
 
-{en_US Word to be completed}.
+Word to be completed.
 
 =back
 
@@ -1195,14 +1175,12 @@ Return value:  (array)
 
 =head2 complete_cli_arg(%args) -> hash
 
-{en_US Complete command-line argument using Rinci function metadata}.
+Complete command-line argument using Rinci function metadata.
 
-{en_US 
 This routine uses C<Perinci::Sub::GetArgs::Argv> to generate C<Getopt::Long>
 specification from arguments list in Rinci function metadata and common options.
 Then, it will use C<Complete::Getopt::Long> to complete option names, option
 values, as well as arguments.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -1210,9 +1188,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<common_opts> => I<hash>
 
-{en_US Common options}.
+Common options.
 
-{en_US 
 A hash where the values are hashes containing these keys: C<getopt> (Getopt::Long
 option specification), C<handler> (Getopt::Long handler). Will be passed to
 C<get_args_from_argv()>. Example:
@@ -1230,13 +1207,10 @@ C<get_args_from_argv()>. Example:
      },
  }
 
-}
-
 =item * B<completion> => I<code>
 
-{en_US Supply custom completion routine}.
+Supply custom completion routine.
 
-{en_US 
 If supplied, instead of the default completion routine, this code will be called
 instead. Will receive all arguments that C<Complete::Getopt::Long> will pass, and
 additionally:
@@ -1248,50 +1222,44 @@ additionally:
 =item * C<args> (hash, the function arguments formed so far)
 
 =item * C<index> (int, if completing argument element value)
-}
 
 =back
 
 =item * B<cword>* => I<int>
 
-{en_US On which argument cursor is located (zero-based)}.
+On which argument cursor is located (zero-based).
 
 =item * B<extras> => I<hash>
 
-{en_US Add extra arguments to completion routine}.
+Add extra arguments to completion routine.
 
-{en_US 
 The keys from this C<extras> hash will be merged into the final C<%args> passed to
 completion routines. Note that standard keys like C<word>, C<cword>, C<ci>, and so
 on as described in the function description will not be overwritten by this.
-}
 
 =item * B<func_arg_starts_at> => I<int> (default: 0)
 
-{en_US 
 This is a (temporary?) workaround for Perinci::CmdLine. In an application with
 subcommands (e.g. C<cmd --verbose subcmd arg0 arg1 ...>), then C<words> will still
 contain the subcommand name. Positional function arguments then start at 1 not
 0. This option allows offsetting function arguments.
-}
 
 =item * B<meta>* => I<hash>
 
-{en_US Rinci function metadata}.
+Rinci function metadata.
 
 =item * B<per_arg_json> => I<bool>
 
-{en_US Will be passed to Perinci::Sub::GetArgs::Argv}.
+Will be passed to Perinci::Sub::GetArgs::Argv.
 
 =item * B<per_arg_yaml> => I<bool>
 
-{en_US Will be passed to Perinci::Sub::GetArgs::Argv}.
+Will be passed to Perinci::Sub::GetArgs::Argv.
 
 =item * B<riap_client> => I<obj>
 
-{en_US Optional, to perform complete_arg_val to the server}.
+Optional, to perform complete_arg_val to the server.
 
-{en_US 
 When the argument spec in the Rinci metadata contains C<completion> key, this
 means there is custom completion code for that argument. However, if retrieved
 from a remote server, sometimes the C<completion> key no longer contains the code
@@ -1301,49 +1269,40 @@ on the server.
 If supplied this argument and te C<riap_server_url> argument, the function will
 try to request to the server (via Riap request C<complete_arg_val>). Otherwise,
 the function will just give up/decline completing.
-}
 
 =item * B<riap_server_url> => I<str>
 
-{en_US Optional, to perform complete_arg_val to the server}.
+Optional, to perform complete_arg_val to the server.
 
-{en_US 
 See the C<riap_client> argument.
-}
 
 =item * B<riap_uri> => I<str>
 
-{en_US Optional, to perform complete_arg_val to the server}.
+Optional, to perform complete_arg_val to the server.
 
-{en_US 
 See the C<riap_client> argument.
-}
 
 =item * B<words>* => I<array[str]>
 
-{en_US Command-line arguments}.
+Command-line arguments.
 
 =back
 
 Return value:  (hash)
 
 
-{en_US 
 You can use C<format_completion> function in C<Complete::Bash> module to format
 the result of this function for bash.
-}
 
 
 =head2 complete_from_schema(%args) -> [status, msg, result, meta]
 
-{en_US Complete a value from schema}.
+Complete a value from schema.
 
-{en_US 
 Employ some heuristics to complete a value from Sah schema. For example, if
 schema is C<< [str =E<gt> in =E<gt> [qw/new open resolved rejected/]] >>, then we can
 complete from the C<in> clause. Or for something like C<< [int =E<gt> between =E<gt> [1,
 20]] >> we can complete using values from 1 to 20.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -1353,7 +1312,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<schema>* => I<any>
 
-{en_US Must be normalized}.
+Must be normalized.
 
 =item * B<word>* => I<str> (default: "")
 
